<?php

App::uses('AppComponent', 'Controller/Component');

class PostStageComponent extends AppComponent {

	/**
	 * check for a process any registration data
	 *
	 * @return bool
	 */
	public function processRegister() {
		$return = true;

		if (isset($this->_controller->request->data['Form']['action']) && $this->_controller->request->data['Form']['action'] == 'register') {

			if (empty($this->_controller->UserManager)) {
				$this->_controller->UserManager = $this->_controller->loadComponent('EvCore.UserManager');
			}

			// move the array data to 'User' section, separated to prevent
			// login / register forms from both populating

			$UserModel = EvClassREgistry::init('EvCore.User');
			$result = $this->_controller->UserManager->register($UserModel);

			if ($result['result'] === true) {
				$this->_controller->Flash->success($result['data']['message']);
			} else {

				$return = false;
				$this->_controller->Flash->fail($result['data']['errors']);
			}
		}

		return $return;
	}

	/**
	 * check for a process any login data
	 *
	 * @return bool
	 */
	public function processLogin() {
		$return = true;

		if (isset($this->_controller->request->data['Form']['action']) && $this->_controller->request->data['Form']['action'] == 'login') {

			if (empty($this->_controller->UserManager)) {
				$this->_controller->UserManager = $this->_controller->loadComponent('EvCore.UserManager');
			}

			// move the array data to 'User' section, separated to prevent
			// login / register forms from both populating
			$this->_controller->request->data['User'] = $this->_controller->request->data['Login'];

			$UserModel = EvClassRegistry::init('EvCore.User');
			$result = $this->_controller->UserManager->login($UserModel);

			if ($result['result'] === true) {
				$this->_controller->Flash->success($result['data']['message']);
			} else {
				$return = false;
				$this->_controller->Flash->fail($result['data']['errors']);
			}
		}

		return $return;
	}

	/**
	 * process the delivery addresses
	 *
	 * @return 	bool
	 */
	public function processDeliveryAddress() {
		if (! CakePlugin::loaded('EvAddressBook')) {
			$this->_controller->Flash->fail('EvAddressBook is not loaded. Cannot retrieve addresses');
			return false;
		}

		$return = true;

		// check to see if we are wanting to add and select an address
		if (isset($this->_controller->request->data['Form']['action']) && $this->_controller->request->data['Form']['action'] == 'addAddress') {
			if (empty($this->_controller->AddressManager)) {
				$this->_controller->AddressManager = $this->_controller->loadComponent('EvAddressBook.AddressManager');
			}

			$AddressModel = EvClassRegistry::init('EvAddressBook.Address');
			$result = $this->_controller->AddressManager->add(
				$AddressModel,
				'EvCore.User',
				$this->_controller->Auth->user('User.id')
			);

			// if successful select the address
			if ($result['result'] === true) {
				$this->_controller->Flash->success($result['data']['message']);
				$this->_setAddress(
					'delivery',
					$result['data']['Address']['id']
				);
			} else {
				$return = false;
				$this->_controller->Flash->fail($result['data']['errors']);
			}
		}

		// check to see if we are wanting to select an existing address
		if (isset($this->_controller->request->data['Form']['action']) && $this->_controller->request->data['Form']['action'] == 'selectAddress') {
			if (empty($this->_controller->AddressManager)) {
				$this->_controller->AddressManager = $this->_controller->loadComponent('EvAddressBook.AddressManager');
			}

			$AddressModel = EvClassRegistry::init('EvAddressBook.Address');
			$result = $this->_controller->AddressManager->addressBelongsToUser(
				$AddressModel,
				$this->_controller->request->data['Address']['id'],
				$this->_controller->Auth->user('User.id')
			);

			if ($result['result'] === true) {
				$this->_setAddress(
					'delivery',
					$this->_controller->request->data['Address']['id']
				);
			} else {
				$return = false;
				$this->_controller->Flash->fail($result['data']['errors']);
			}
		}

		return $return;
	}

	/**
	 * set the selected address to a session
	 *
	 * @param 	string 	$type 		Type of address (billing / devliery)
	 * @param 	int 	$addressId 	Address row ID
	 * @return 	bool
	 */
	protected function _setAddress($type, $addressId) {
		return $this->_controller->Session->write(
			'EvCheckout.address.' . $type,
			$addressId
		);
	}
}
